@@ -1,9 +1,9 @@
 /*
  * psql - the PostgreSQL interactive terminal
  *
- * Copyright 2000-2002 by PostgreSQL Global Development Group
+ * Copyright (c) 2000-2003, PostgreSQL Global Development Group
  *
- * $Header: /cvsroot/pgsql/src/bin/psql/describe.h,v 1.18 2002/08/27 18:28:29 momjian Exp $
+ * $Header: /cvsroot/pgsql/src/bin/psql/describe.h,v 1.21 2003/08/04 23:59:40 tgl Exp $
  */
 #ifndef DESCRIBE_H
 #define DESCRIBE_H
@@ -43,4 +43,14 @@ bool		listTables(const char *tabtypes, const char *pattern, bool verbose);
 /* \dD */
 bool		listDomains(const char *pattern);
 
+/* \dc */
+bool		listConversions(const char *pattern);
+
+/* \dC */
+bool		listCasts(const char *pattern);
+
+/* \dn */
+bool		listSchemas(const char *pattern);
+
+
 #endif   /* DESCRIBE_H */
